# Distilled from 2100+ lines of Makefile.in noise
# J. Welsh, January 2018

CFLAGS = -Wall
CPPFLAGS = $(addprefix -I,generic unix libtommath) $(addprefix -D,HAVE_UNISTD_H HAVE_INTPTR_T HAVE_UINTPTR_T BUILD_tcl)

prefix = /usr/local
bindir = $(prefix)/bin
libdir = $(prefix)/lib
scriptdir = $(prefix)/lib/tcl
includedir = $(prefix)/include
mandir = $(prefix)/man

GENERIC_OBJS = $(addprefix generic/,regcomp regexec regfree regerror) $(addprefix generic/tcl,Alloc Assembly Async Basic Binary Ckalloc Clock CmdAH CmdIL CmdMZ CompCmds CompCmdsGR CompCmdsSZ CompExpr Compile Config Date DictObj Disassemble Encoding Ensemble Env Event Execute FCmd FileName Get Hash History IndexObj Interp IO IOCmd IORChan IORTrans IOGT IOSock IOUtil Link ListObj Literal Load LoadNone Main Namesp Notify Obj Optimize Panic Parse PathObj Pipe Pkg PkgConfig PosixStr Preserve Proc Regexp Resolve Result Scan StringObj StrToD Thread ThreadAlloc ThreadJoin ThreadStorage StubInit Timer Trace Utf Util Var Zlib TomMathInterface)

OO_OBJS = $(addprefix generic/tcl,OO OOBasic OOCall OODefineCmds OOInfo OOMethod OOStubInit)

TOMMATH_OBJS = $(addprefix libtommath/,bncore bn_reverse bn_fast_s_mp_mul_digs bn_fast_s_mp_sqr bn_mp_add bn_mp_and bn_mp_add_d bn_mp_clamp bn_mp_clear bn_mp_clear_multi bn_mp_cmp bn_mp_cmp_d bn_mp_cmp_mag bn_mp_cnt_lsb bn_mp_copy bn_mp_count_bits bn_mp_div bn_mp_div_d bn_mp_div_2 bn_mp_div_2d bn_mp_div_3 bn_mp_exch bn_mp_expt_d bn_mp_grow bn_mp_init bn_mp_init_copy bn_mp_init_multi bn_mp_init_set bn_mp_init_set_int bn_mp_init_size bn_mp_karatsuba_mul bn_mp_karatsuba_sqr bn_mp_lshd bn_mp_mod bn_mp_mod_2d bn_mp_mul bn_mp_mul_2 bn_mp_mul_2d bn_mp_mul_d bn_mp_neg bn_mp_or bn_mp_radix_size bn_mp_radix_smap bn_mp_read_radix bn_mp_rshd bn_mp_set bn_mp_set_int bn_mp_shrink bn_mp_sqr bn_mp_sqrt bn_mp_sub bn_mp_sub_d bn_mp_to_unsigned_bin bn_mp_to_unsigned_bin_n bn_mp_toom_mul bn_mp_toom_sqr bn_mp_toradix_n bn_mp_unsigned_bin_size bn_mp_xor bn_mp_zero bn_s_mp_add bn_s_mp_mul_digs bn_s_mp_sqr bn_s_mp_sub)

UNIX_OBJS = $(addprefix unix/tclUnix,Chan Event FCmd File Pipe Sock Time Init Thrd Compat Notfy)

OBJS = $(addsuffix .o,$(GENERIC_OBJS) $(UNIX_OBJS) $(OO_OBJS) $(TOMMATH_OBJS))

tclsh: unix/tclAppInit.o libtcl.a
	$(CC) $(LDFLAGS) -o $@ $^

libtcl.a: $(OBJS)
	$(AR) -cr $@ $^

# the CFG_INSTALL_* were relative to DESTDIR which is nonsense...
generic/tclPkgConfig.o: generic/tclPkgConfig.c
	$(CC) $(CFLAGS) $(CPPFLAGS) \
		-DCFG_INSTALL_LIBDIR="\"$(libdir)\"" \
		-DCFG_INSTALL_BINDIR="\"$(bindir)\"" \
		-DCFG_INSTALL_SCRDIR="\"$(scriptdir)\"" \
		-DCFG_INSTALL_INCDIR="\"$(includedir)\"" \
		-DCFG_INSTALL_DOCDIR="\"$(mandir)\"" \
		-DCFG_RUNTIME_LIBDIR="\"$(libdir)\"" \
		-DCFG_RUNTIME_BINDIR="\"$(bindir)\"" \
		-DCFG_RUNTIME_SCRDIR="\"$(scriptdir)\"" \
		-DCFG_RUNTIME_INCDIR="\"$(includedir)\"" \
		-DCFG_RUNTIME_DOCDIR="\"$(mandir)\"" \
		-DTCL_CFGVAL_ENCODING=NULL \
		-c $< -o $@

unix/tclUnixInit.o: unix/tclUnixInit.c
	$(CC) $(CFLAGS) $(CPPFLAGS) \
		-DTCL_LIBRARY="\"$(scriptdir)\"" \
		-DTCL_PACKAGE_PATH="\"$(libdir)\"" \
		-c $< -o $@

clean:
	rm -f tclsh libtcl.a unix/tclAppInit.o $(OBJS)
